#!/bin/bash
LISTEN_PORT=8080
TYK_NODE_HOSTNAME="localhost"
TYK_NODE_PORT="8080"
MONGO_URL="mongodb://localhost/tyk_analytics"
REDIS_PORT=6379
REDIS_HOST="localhost"
REDIS_PASSWORD=""
API_HOSTNAME="tyk.local"
DASHBOARD_HOSTNAME="dashboard.tyk.local"
PORTAL_ROOT="/portal"



DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

for i in "$@"
do
case $i in
	-l=*|--listenport=*)
    LISTEN_PORT="${i#*=}"
    shift # past argument=value
    ;;
    -r=*|--redishost=*)
    REDIS_HOST="${i#*=}"
    shift # past argument=value
    ;;
    -p=*|--redisport=*)
    REDIS_PORT="${i#*=}"
    shift # past argument=value
    ;;
    -s=*|--redispass=*)
    REDIS_PASSWORD="${i#*=}"
    shift # past argument=value
    ;;
    -d=*|--domain=*)
    DASHBOARD_HOSTNAME="${i#*=}"
    shift # past argument=value
    ;;
    -m=*|--mongo=*)
    MONGO_URL="${i#*=}"
    shift # past argument=value
    ;;
    -a=*|--tyk_api_hostname=*)
    API_HOSTNAME="${i#*=}"
    shift # past argument=value
    ;;
    -t=*|--tyk_node_hostname=*)
    TYK_NODE_HOSTNAME="${i#*=}"
    shift # past argument=value
    ;;
    -w=*|--tyk_node_port=*)
    TYK_NODE_PORT="${i#*=}"
    shift # past argument=value
    ;;
    -q=*|--portal_root=*)
    PORTAL_ROOT="${i#*=}"
    shift # past argument=value
    ;;
    --default)
    DEFAULT=YES
    shift # past argument with no value
    ;;
    *)
            # unknown option
    ;;
esac
done

echo "Listen Port   = ${LISTEN_PORT}"
echo "Redis Host    = ${REDIS_HOST}"
echo "Redis Port    = ${REDIS_PORT}"
echo "Redis PW      = ${REDIS_PASSWORD}"
echo "Mongo URL     = ${MONGO_URL}"
echo "API Hostname  = ${API_HOSTNAME}"
echo "Tyk Node      = ${TYK_NODE_HOSTNAME}"
echo "Tyk Port      = ${TYK_NODE_PORT}"
echo "Dash Hostname = ${DASHBOARD_HOSTNAME}"
echo "Portal Root   = ${PORTAL_ROOT}"

# Set up the editing file
TEMPLATE_FILE="tyk_analytics_template.conf"
cp $DIR/data/$TEMPLATE_FILE $DIR/tyk_analytics.conf

# Update variables
sed -i 's/LISTEN_PORT/'$LISTEN_PORT'/g' $DIR/tyk_analytics.conf
sed -i 's/REDIS_HOST/'$REDIS_HOST'/g' $DIR/tyk_analytics.conf
sed -i 's/REDIS_PORT/'$REDIS_PORT'/g' $DIR/tyk_analytics.conf
sed -i 's/REDIS_PASSWORD/'$REDIS_PASSWORD'/g' $DIR/tyk_analytics.conf
sed -i 's#MONGO_URL#'$MONGO_URL'#g' $DIR/tyk_analytics.conf
sed -i 's#TYK_NODE_HOSTNAME#'$TYK_NODE_HOSTNAME'#g' $DIR/tyk_analytics.conf
sed -i 's#TYK_NODE_PORT#'$TYK_NODE_PORT'#g' $DIR/tyk_analytics.conf
sed -i 's#API_HOSTNAME#'$API_HOSTNAME'#g' $DIR/tyk_analytics.conf
sed -i 's#DASHBOARD_HOSTNAME#'$DASHBOARD_HOSTNAME'#g' $DIR/tyk_analytics.conf
sed -i 's#PORTAL_ROOT#'$PORTAL_ROOT'#g' $DIR/tyk_analytics.conf

echo "==> File written to ./tyk_analytics.conf"
sudo cp $DIR/tyk_analytics.conf $DIR/../tyk_analytics.conf
echo "==> File copied to $DIR/../tyk_analytics.conf"