const path = require('path');
const webpack = require('webpack');
const ExtractTextPlugin = require('extract-text-webpack-plugin');
const environment = process.env.NODE_ENV;
const ExtractAppCSS = new ExtractTextPlugin({
  filename: '[name].css',
  allChunks: true
});
const UglifyJsPlugin = require('uglifyjs-webpack-plugin')

let config = {
  entry: {
    'portal-assets/js/swagger.min': './portal-assets/js/swagger.js',
    'portal-assets/js/vendors.min': './portal-assets/js/vendors.js',
    'portal-assets/css/swagger.min': './portal-assets/css/swagger.scss'
  },
  output: {
    path: path.resolve(__dirname),
    filename: '[name].js',
    library: 'TykDeveloperPortal'
  },
  watch: true,
  watchOptions: {
    aggregateTimeout: 300,
    poll: 1000
  },
  module: {
    rules: [
      {
        test: /\.scss$/,
        use: ExtractAppCSS.extract({
          fallback: 'style-loader',
          use: [
            {
              loader: 'css-loader',
              options: {
                minimize: true,
                sourceMap: true
              }
            },
            'postcss-loader',
            'resolve-url-loader',
            {
              loader: 'sass-loader',
              options: {
                sourceMap: true
              }
            }
          ]
        })
      },
      {
        test: /\.css$/,
        use: ExtractAppCSS.extract({
          fallback: 'style-loader',
          use: [
            {
              loader: 'css-loader',
              options: {
                url: false,
                minimize: true,
                sourceMap: true
              }
            },
            'postcss-loader',
            'resolve-url-loader',
          ]
        })
      },
      {
        test: /\.(jpg|png)$/,
        use: {
          loader: 'file-loader',
          options: {
            name: './images/[name].[ext]'
          }
        }
      },
      {
        test: /\.(ttf|otf|eot|svg|woff(2)?)(\?[a-z0-9]+)?$/,
        use: {
          loader: 'file-loader',
          options: {
            name: '[name].[ext]'
          }
        }
      },
      {
        test: /\.jsx?$/,
        loader: 'babel-loader',
        exclude: /(node_modules(?!\/webpack-dev-server)|bower_components)/,
        options: {
          presets: ['react', 'env']
        },
      }
    ]
  },
  stats: 'errors-only',
  devServer: {
    contentBase: path.join(__dirname, './'),
    compress: true,
    historyApiFallback: true,
    hot: true,
    https: false,
    noInfo: true,
  },
  plugins: [
    new webpack.optimize.CommonsChunkPlugin({
      name : 'portal-assets/js/vendors.min',
      //filename: 'portal-assets/js/vendors.min.js',
      hash: true,
      minChunks: Infinity
    }),
    new webpack.DefinePlugin({
      'process.env': {
        NODE_ENV: JSON.stringify(environment)
      }
    }),
    new webpack.ProvidePlugin({
      $: 'jquery',
      jQuery: 'jquery',
      'window.$': 'jquery',
      'window.jQuery': 'jquery'
    }),
    ExtractAppCSS
  ],
  resolveLoader: { /* same as resolve */ },
  parallelism: 1,
  profile: true,
  bail: true,
  cache: false,
  watch: false,
  watchOptions: {
    aggregateTimeout: 1000,
    poll: true,
    poll: 500,
  },
  node: {
    console: false,
    global: true,
    process: true,
    __filename: 'mock',
    __dirname: 'mock',
    Buffer: true,
    setImmediate: true
  }
};

if(environment === 'development') {
  config.devtool = 'source-map';
} else {
  config.plugins.push(
    new UglifyJsPlugin()
  );
}

module.exports = config;
